module.exports = defineTest({
	description: 'adds semi-colons if necessary'
});
